
Featurizers
-----------

Pore geometry featurization
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
.. automodule:: mofdscribe.featurizers.pore.geometric_properties
    :members:


Voxelgrid
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
.. automodule:: mofdscribe.featurizers.pore.voxelgrid
    :members:

Topological featurization (persistent homology)
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

Note that under topology we understand here the embedding topology
and not the one of the underlying structure graph (i.e. the connectivity).

.. automodule:: mofdscribe.featurizers.topology.ph_vect
    :members:

.. automodule:: mofdscribe.featurizers.topology.ph_image
    :members:

.. automodule:: mofdscribe.featurizers.topology.atom_centered_ph
    :members:

.. automodule:: mofdscribe.featurizers.topology.ph_stats
     :members:

.. automodule:: mofdscribe.featurizers.topology.ph_hist
     :members:

Chemistry-centred featurization
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: mofdscribe.featurizers.chemistry.racs
    :members:

.. automodule:: mofdscribe.featurizers.chemistry.aprdf
    :members:

.. automodule:: mofdscribe.featurizers.chemistry.partialchargestats
    :members:

.. automodule:: mofdscribe.featurizers.chemistry.partialchargehistogram
    :members:

.. automodule:: mofdscribe.featurizers.chemistry.energygrid
    :members:

.. automodule:: mofdscribe.featurizers.chemistry.amd
    :members:


BU-centred featurization
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: mofdscribe.featurizers.bu.bu_matches
    :members:

.. automodule:: mofdscribe.featurizers.bu.rdkitadaptor
    :members:

.. automodule:: mofdscribe.featurizers.bu.bu_featurizer
    :members:

.. automodule:: mofdscribe.featurizers.bu.lsop_featurizer
    :members:

.. automodule:: mofdscribe.featurizers.bu.nconf20_featurizer
    :members:

.. automodule:: mofdscribe.featurizers.bu.compositionstats_featurizer
    :members:

.. automodule:: mofdscribe.featurizers.bu.distance_stats_featurizer
    :members:

.. automodule:: mofdscribe.featurizers.bu.distance_hist_featurizer
    :members:

.. automodule:: mofdscribe.featurizers.bu.shape_featurizer
    :members:

.. automodule:: mofdscribe.featurizers.bu.smarts_matches
    :members:


Host Guest featurization
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: mofdscribe.featurizers.hostguest.host_guest_featurizer
    :members: